==> dde-shell_2.0.1.tar.xz: BUILD/panels/dock/translations/org.deepin.ds.dock_es.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="es">
<context>
    <name>main</name>
    <message>
        <source>Indicator Style</source>
        <translation>Estilo de indicador</translation>
    </message>
    <message>
        <source>Fashion Mode</source>
        <translation>Modo elegante</translation>
    </message>
    <message>
        <source>Efficient Mode</source>
        <translation>Modo eficiente</translation>
    </message>
    <message>
        <source>Classic Mode</source>
        <translation>Modo clásico</translation>
    </message>
    <message>
        <source>Centered Mode</source>
        <translation>Modo centrado</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Izquierda</translation>
    </message>
    <message>
        <source>Position</source>
        <translation>Posición</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Modo</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>Arriba</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>Abajo</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Derecha</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Estado</translation>
    </message>
    <message>
        <source>Keep Shown</source>
        <translation>Mantener visible</translation>
    </message>
    <message>
        <source>Keep Hidden</source>
        <translation>Mantener oculto</translation>
    </message>
    <message>
        <source>Smart Hide</source>
        <translation>Ocultado inteligente</translation>
    </message>
    <message>
        <source>Dock Settings</source>
        <translation>Ajustes del muelle</translation>
    </message>
    <message>
        <source>Lock the Dock</source>
        <translation>Bloquear muelle</translation>
    </message>
</context>
</TS>

==> dde-shell_2.0.19.2.tar.xz: BUILD/panels/dock/translations/org.deepin.ds.dock_es.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="es">
<context>
    <name>main</name>
    <message>
        <source>Indicator Style</source>
        <translation>Estilo de indicador</translation>
    </message>
    <message>
        <source>Fashion Mode</source>
        <translation>Modo elegante</translation>
    </message>
    <message>
        <source>Efficient Mode</source>
        <translation>Modo eficiente</translation>
    </message>
    <message>
        <source>Classic Mode</source>
        <translation>Modo clásico</translation>
    </message>
    <message>
        <source>Centered Mode</source>
        <translation>Modo centrado</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Izquierda</translation>
    </message>
    <message>
        <source>Position</source>
        <translation>Posición</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Modo</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>Arriba</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>Abajo</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Derecha</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Estado</translation>
    </message>
    <message>
        <source>Keep Shown</source>
        <translation>Mantener visible</translation>
    </message>
    <message>
        <source>Keep Hidden</source>
        <translation>Mantener oculto</translation>
    </message>
    <message>
        <source>Smart Hide</source>
        <translation>Ocultado inteligente</translation>
    </message>
    <message>
        <source>Dock Settings</source>
        <translation>Ajustes del muelle</translation>
    </message>
    <message>
        <source>Lock the Dock</source>
        <translation>Bloquear el muelle</translation>
    </message>
</context>
</TS>
